summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp b/experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp
index 7458db63e..8784e4dbc 100644
--- a/experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp
+++ b/experimental/tqtinterface/qt4/src/codecs/tqtextcodec.cpp
@@ -320,7 +320,7 @@ TQString TQTextStatelessDecoder::toUnicode(const char* chars, int len)
recently created TQTextCodec objects take precedence over earlier
ones.
- You may tqfind it more convenient to make your codec class available
+ You may find it more convenient to make your codec class available
as a plugin; see the \link plugins-howto.html plugin
documentation\endlink for more details.
@@ -872,7 +872,7 @@ TQTextCodec* TQTextCodec::codecForName( const char* name, int accuracy )
often use most of the available character sequences, and so only
by linguistic analysis could a true match be made.
- \a chars tqcontains the string to check, and \a len tqcontains the
+ \a chars contains the string to check, and \a len contains the
number of characters in the string to use.
\sa heuristicContentMatch()
@@ -944,7 +944,7 @@ const char* TQTextCodec::mimeName() const
the first \a len bytes of \a chars and returns a value indicating
how likely it is that the string is a prefix of text encoded in
the encoding of the subclass. A negative return value indicates
- that the text is detectably not in the encoding (e.g. it tqcontains
+ that the text is detectably not in the encoding (e.g. it contains
characters undefined in the encoding). A return value of 0
indicates that the text should be decoded with this codec rather
than as ASCII, but there is no particular evidence. The value
@@ -1064,7 +1064,7 @@ TQCString TQTextCodec::fromUnicode(const TQString& uc) const
/*!
\overload
- \a a tqcontains the source characters; \a len tqcontains the number of
+ \a a contains the source characters; \a len contains the number of
characters in \a a to use.
*/
TQString TQTextCodec::toUnicode(const TQByteArray& a, int len) const
@@ -1077,7 +1077,7 @@ TQString TQTextCodec::toUnicode(const TQByteArray& a, int len) const
/*!
\overload
- \a a tqcontains the source characters.
+ \a a contains the source characters.
*/
TQString TQTextCodec::toUnicode(const TQByteArray& a) const
{
@@ -1088,7 +1088,7 @@ TQString TQTextCodec::toUnicode(const TQByteArray& a) const
/*!
\overload
- \a a tqcontains the source characters; \a len tqcontains the number of
+ \a a contains the source characters; \a len contains the number of
characters in \a a to use.
*/
TQString TQTextCodec::toUnicode(const TQCString& a, int len) const
@@ -1101,7 +1101,7 @@ TQString TQTextCodec::toUnicode(const TQCString& a, int len) const
/*!
\overload
- \a a tqcontains the source characters.
+ \a a contains the source characters.
*/
TQString TQTextCodec::toUnicode(const TQCString& a) const
{
@@ -1112,7 +1112,7 @@ TQString TQTextCodec::toUnicode(const TQCString& a) const
/*!
\overload
- \a chars tqcontains the source characters.
+ \a chars contains the source characters.
*/
TQString TQTextCodec::toUnicode(const char* chars) const
{
@@ -1149,7 +1149,7 @@ bool TQTextCodec::canEncode( TQChar ch ) const
/*!
\overload
- \a s tqcontains the string being tested for encode-ability.
+ \a s contains the string being tested for encode-ability.
*/
bool TQTextCodec::canEncode( const TQString& s ) const
{
@@ -2657,7 +2657,7 @@ TQString TQLatin15Codec::toUnicode(const char* chars, int len) const
}
static inline unsigned char
-latin15CharFromUnicode( unsigned short uc, bool tqreplacement = TRUE )
+latin15CharFromUnicode( unsigned short uc, bool replacement = TRUE )
{
uchar c;
if ( uc < 0x0100 ) {
@@ -2671,7 +2671,7 @@ latin15CharFromUnicode( unsigned short uc, bool tqreplacement = TRUE )
case 0xbc:
case 0xbd:
case 0xbe:
- c = tqreplacement ? '?' : 0;
+ c = replacement ? '?' : 0;
break;
default:
c = (unsigned char) uc;
@@ -2707,10 +2707,10 @@ latin15CharFromUnicode( unsigned short uc, bool tqreplacement = TRUE )
c = 0xbe;
break;
default:
- c = tqreplacement ? '?' : 0;
+ c = replacement ? '?' : 0;
}
} else {
- c = tqreplacement ? '?' : 0;
+ c = replacement ? '?' : 0;
}
}
return c;
@@ -2818,20 +2818,20 @@ static void setupLocaleMapper()
}
// Now try these in order:
// 1. CODESET from ctype if it tqcontains a .CODESET part (e.g. en_US.ISO8859-15)
// 2. CODESET from lang if it tqcontains a .CODESET part
// 3. ctype (maybe the locale is named "ISO-8859-1" or something)
// 4. locale (ditto)
// 5. check for "@euro"
// 6. guess locale from ctype unless ctype is "C"
// 7. guess locale from lang
// 1. CODESET from ctype if it tqcontains a .CODESET part (e.g. en_US.ISO8859-15)
char * codeset = ctype ? strchr( ctype, '.' ) : 0;
if ( codeset && *codeset == '.' )
localeMapper = checkForCodec( codeset + 1 );
// 2. CODESET from lang if it tqcontains a .CODESET part
codeset = lang ? strchr( lang, '.' ) : 0;
if ( !localeMapper && codeset && *codeset == '.' )
localeMapper = checkForCodec( codeset + 1 );
@@ -2818,20 +2818,20 @@ static void setupLocaleMapper()
}
// Now try these in order:
- // 1. CODESET from ctype if it tqcontains a .CODESET part (e.g. en_US.ISO8859-15)
- // 2. CODESET from lang if it tqcontains a .CODESET part
+ // 1. CODESET from ctype if it contains a .CODESET part (e.g. en_US.ISO8859-15)
+ // 2. CODESET from lang if it contains a .CODESET part
// 3. ctype (maybe the locale is named "ISO-8859-1" or something)
// 4. locale (ditto)
@@ -2818,20 +2818,20 @@ static void setupLocaleMapper()
// 6. guess locale from ctype unless ctype is "C"
// 7. guess locale from lang
- // 1. CODESET from ctype if it tqcontains a .CODESET part (e.g. en_US.ISO8859-15)
+ // 1. CODESET from ctype if it contains a .CODESET part (e.g. en_US.ISO8859-15)
char * codeset = ctype ? strchr( ctype, '.' ) : 0;
if ( codeset && *codeset == '.' )
@@ -2818,20 +2818,20 @@ static void setupLocaleMapper()
if ( codeset && *codeset == '.' )
localeMapper = checkForCodec( codeset + 1 );
- // 2. CODESET from lang if it tqcontains a .CODESET part
+ // 2. CODESET from lang if it contains a .CODESET part
codeset = lang ? strchr( lang, '.' ) : 0;
if ( !localeMapper && codeset && *codeset == '.' )